Documentation
¶
Index ¶
- type ArgumentOption
- type CallExprOption
- type Enum
- type EnumOption
- type EnumValue
- type EnumValueOption
- type Field
- type FieldOneof
- type FieldOption
- type File
- func (f *File) AST() *ast.FileNode
- func (f *File) Content() []byte
- func (f *File) FindLocationByPos(pos Position) *Location
- func (f *File) Imports() []string
- func (f *File) NodeInfoByLocation(loc *Location) *ast.NodeInfo
- func (f *File) Path() string
- func (f *File) SemanticTokenTypeMap() map[ast.Token]protocol.SemanticTokenTypes
- type IteratorOption
- type Location
- func CallExprMethodLocation(fileName, msgName string, defIdx int) *Location
- func CallExprRequestByLocation(fileName, msgName string, defIdx, reqIdx int) *Location
- func EnumAliasLocation(fileName, msgName, enumName string) *Location
- func EnumLocation(fileName, msgName, enumName string) *Location
- func EnumOptionLocation(fileName, msgName, enumName string) *Location
- func EnumValueAliasLocation(fileName, msgName, enumName, enumValueName string) *Location
- func EnumValueLocation(fileName, msgName, enumName, enumValueName string) *Location
- func EnumValueOptionLocation(fileName, msgName, enumName, enumValueName string) *Location
- func FileLocation(fileName string) *Location
- func GoPackageLocation(fileName string) *Location
- func MapExprByLocation(fileName, msgName string, defIdx int) *Location
- func MapExprMessageLocation(fileName, msgName string, defIdx int) *Location
- func MapExprMessageNameLocation(fileName, msgName string, defIdx int) *Location
- func MapIteratorNameLocation(fileName, msgName string, defIdx int) *Location
- func MapIteratorSourceLocation(fileName, msgName string, defIdx int) *Location
- func MapMessageExprArgumentByLocation(fileName, msgName string, defIdx, argIdx int) *Location
- func MapMessageExprArgumentInlineLocation(fileName, msgName string, defIdx, argIdx int) *Location
- func MessageAliasLocation(fileName, msgName string) *Location
- func MessageExprArgumentByLocation(fileName, msgName string, idx, argIdx int) *Location
- func MessageExprArgumentInlineLocation(fileName, msgName string, idx, argIdx int) *Location
- func MessageExprArgumentLocation(fileName, msgName string, idx, argIdx int) *Location
- func MessageExprArgumentNameLocation(fileName, msgName string, idx, argIdx int) *Location
- func MessageExprLocation(fileName, msgName string, defIdx int) *Location
- func MessageExprNameLocation(fileName, msgName string, idx int) *Location
- func MessageFieldByLocation(fileName, msgName, fieldName string) *Location
- func MessageFieldLocation(fileName, msgName, fieldName string) *Location
- func MessageFieldOneofByLocation(fileName, msgName, fieldName string) *Location
- func MessageFieldOneofDefMessageArgumentLocation(fileName, msgName, fieldName string, idx, argIdx int) *Location
- func MessageFieldOneofDefMessageLocation(fileName, msgName, fieldName string, idx int) *Location
- func MessageFieldOneofDefaultLocation(fileName, msgName, fieldName string) *Location
- func MessageFieldOneofIfLocation(fileName, msgName, fieldName string) *Location
- func MessageFieldOneofLocation(fileName, msgName, fieldName string) *Location
- func MessageFieldOptionLocation(fileName, msgName, fieldName string) *Location
- func MessageLocation(fileName, msgName string) *Location
- func MessageOptionLocation(fileName, msgName string) *Location
- func MethodLocation(fileName, msgName string, idx int) *Location
- func MethodRetryConstantIntervalLocation(fileName, msgName string, idx int) *Location
- func MethodRetryExponentialInitialIntervalLocation(fileName, msgName string, idx int) *Location
- func MethodRetryExponentialMaxIntervalLocation(fileName, msgName string, idx int) *Location
- func MethodTimeoutLocation(fileName, msgName string, idx int) *Location
- func OneofOptionLocation(fileName, msgName, oneofName string) *Location
- func RequestByLocation(fileName, msgName string, defIdx, reqIdx int) *Location
- func RequestFieldLocation(fileName, msgName string, defIdx, reqIdx int) *Location
- func ServiceDependencyLocation(fileName, svcName string, idx int) *Location
- func ServiceDependencyNameLocation(fileName, svcName string, idx int) *Location
- func ServiceDependencyServiceLocation(fileName, svcName string, idx int) *Location
- func ServiceLocation(fileName, svcName string) *Location
- func ServiceMethodLocation(fileName, svcName, methodName string) *Location
- func ServiceMethodOptionLocation(fileName, svcName, methodName string) *Location
- func ServiceMethodRequestLocation(fileName, svcName, methodName string) *Location
- func ServiceMethodResponseLocation(fileName, svcName, methodName string) *Location
- func ServiceMethodTimeoutLocation(fileName, svcName, methodName string) *Location
- func ServiceOptionLocation(fileName, svcName string) *Location
- func ValidationDetailBadRequestLocation(fileName, msgName string, vIdx, dIdx, bIdx, fvIdx int, fieldName string) *Location
- func ValidationDetailLocalizedMessageLocation(fileName, msgName string, vIdx, dIdx, lIdx int, fieldName string) *Location
- func ValidationDetailLocation(fileName, msgName string, vIdx, dIdx int, ifExpr bool) *Location
- func ValidationDetailPreconditionFailureLocation(fileName, msgName string, vIdx, dIdx, fIdx, fvIdx int, fieldName string) *Location
- func ValidationLocation(fileName, msgName string, idx int, ifExpr bool) *Location
- func VariableDefinitionByLocation(fileName, msgName string, defIdx int) *Location
- func VariableDefinitionIfLocation(fileName, msgName string, defIdx int) *Location
- func VariableDefinitionLocation(fileName, msgName string, defIdx int) *Location
- func VariableDefinitionValidationDetailMessageArgumentLocation(fileName, msgName string, defIdx, detIdx, msgIdx, argIdx int) *Location
- func VariableDefinitionValidationDetailMessageLocation(fileName, msgName string, defIdx, detIdx, msgIdx int) *Location
- func VariableDefinitionValidationDetailMessageNameLocation(fileName, msgName string, defIdx, detIdx, msgIdx int) *Location
- type MapExprOption
- type Message
- type MessageExprOption
- type MessageOption
- type Method
- type MethodOption
- type Oneof
- type OneofOption
- type Position
- type RequestOption
- type RetryConstantOption
- type RetryExponentialOption
- type RetryOption
- type Service
- type ServiceDependencyOption
- type ServiceOption
- type ValidationDetailBadRequestFieldViolationOption
- type ValidationDetailBadRequestOption
- type ValidationDetailLocalizedMessageOption
- type ValidationDetailMessageOption
- type ValidationDetailOption
- type ValidationDetailPreconditionFailureOption
- type ValidationDetailPreconditionFailureViolationOption
- type ValidationExprOption
- type VariableDefinitionOption
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ArgumentOption ¶
ArgumentOption represents message argument location of grpc.federation.message option.
type CallExprOption ¶ added in v0.6.0
type CallExprOption struct {
Method bool
Request *RequestOption
Timeout bool
Retry *RetryOption
}
CallExprOption represents def.call location of grpc.federation.message option.
type Enum ¶
type Enum struct {
Name string
Option *EnumOption
Value *EnumValue
}
Enum represents enum location.
type EnumOption ¶
type EnumOption struct {
Alias bool
}
EnumOption represents grpc.federation.enum option location.
type EnumValue ¶
type EnumValue struct {
Value string
Option *EnumValueOption
}
EnumValue represents enum value location.
type EnumValueOption ¶
EnumValueOption represents grpc.federation.enum_value option location.
type Field ¶
type Field struct {
Name string
Option *FieldOption
}
Field represents message field location.
type FieldOneof ¶ added in v0.3.0
type FieldOneof struct {
If bool
Default bool
VariableDefinitions *VariableDefinitionOption
By bool
}
FieldOneof represents grpc.federation.field.oneof location.
type FieldOption ¶
type FieldOption struct {
By bool
Alias bool
Oneof *FieldOneof
}
FieldOption represents grpc.federation.field option location.
type File ¶
type File struct {
// contains filtered or unexported fields
}
func (*File) FindLocationByPos ¶
FindLocationByPos returns the corresponding location information from the position in the source code.
func (*File) NodeInfoByLocation ¶
NodeInfoByLocation returns information about the node at the position specified by location in the AST of the Protocol Buffers.
func (*File) SemanticTokenTypeMap ¶
func (f *File) SemanticTokenTypeMap() map[ast.Token]protocol.SemanticTokenTypes
type IteratorOption ¶ added in v0.6.0
IteratorOption represents def.map.iterator location of grpc.federation.message option.
type Location ¶
type Location struct {
FileName string
GoPackage bool
Service *Service
Message *Message
Enum *Enum
}
Location represents semantic location information for grpc federation option.
func CallExprMethodLocation ¶ added in v0.6.0
CallExprMethodLocation creates location for def.call.method in grpc.federation.message.
func CallExprRequestByLocation ¶ added in v0.6.0
CallExprRequestByLocation creates location for def.call.request.by in grpc.federation.message.
func EnumAliasLocation ¶
EnumAliasLocation creates location for alias in grpc.federation.enum option.
func EnumLocation ¶
EnumLocation creates location for enum.
func EnumOptionLocation ¶
EnumOptionLocation creates location for grpc.federation.enum option.
func EnumValueAliasLocation ¶
EnumValueAliasLocation creates location for alias in grpc.federation.enum_value option.
func EnumValueLocation ¶
EnumValueLocation creates location for enum value.
func EnumValueOptionLocation ¶
EnumValueOptionLocation creates location for grpc.federation.enum_value option.
func FileLocation ¶
FileLocation creates location for file.
func GoPackageLocation ¶
GoPackageLocation creates location for go_package option.
func MapExprByLocation ¶ added in v0.6.0
MapExprByLocation creates location for def.map.by in grpc.federation.message.
func MapExprMessageLocation ¶ added in v0.7.1
MapExprMessageLocation creates location for def.map.message in grpc.federation.message.
func MapExprMessageNameLocation ¶ added in v0.7.1
MapExprMessageNameLocation creates location for def.map.message.name in grpc.federation.message.
func MapIteratorNameLocation ¶ added in v0.6.0
MapIteratorNameLocation creates location for def.map.iterator.name in grpc.federation.message.
func MapIteratorSourceLocation ¶ added in v0.6.0
MapIteratorSourceLocation creates location for def.map.iterator.src in grpc.federation.message.
func MapMessageExprArgumentByLocation ¶ added in v0.6.0
MapMessageExprArgumentByLocation creates location for def.map.message.args[*].by in grpc.federation.message.
func MapMessageExprArgumentInlineLocation ¶ added in v0.6.0
MapMessageExprArgumentInlineLocation creates location for def.map.message.args[*].inline in grpc.federation.message.
func MessageAliasLocation ¶
MessageAliasLocation creates location for alias in grpc.federaiton.message option.
func MessageExprArgumentByLocation ¶ added in v0.6.0
MessageExprArgumentByLocation creates location for messages[*].args[*].by in grpc.federation.message.
func MessageExprArgumentInlineLocation ¶ added in v0.6.0
MessageExprArgumentInlineLocation creates location for def[*].message.args[*].inline in grpc.federation.message.
func MessageExprArgumentLocation ¶ added in v0.7.0
MessageExprArgumentLocation creates location for def[*].message.args[*] in grpc.federation.message.
func MessageExprArgumentNameLocation ¶ added in v0.7.0
MessageExprArgumentNameLocation creates location for def[*].message.args[*].name in grpc.federation.message.
func MessageExprLocation ¶ added in v0.6.0
MessageExprLocation creates location for def[*].message in grpc.federation.message.
func MessageExprNameLocation ¶ added in v0.6.0
MessageExprNameLocation creates location for def[*].message.name in grpc.federation.message.
func MessageFieldByLocation ¶
MessageFieldByLocation creates location for by in grpc.federation.field option.
func MessageFieldLocation ¶
MessageFieldLocation creates location for message field.
func MessageFieldOneofByLocation ¶ added in v0.3.0
MessageFieldOneofByLocation creates location for by in grpc.federation.field.oneof option.
func MessageFieldOneofDefMessageArgumentLocation ¶ added in v0.7.0
func MessageFieldOneofDefMessageArgumentLocation(fileName, msgName, fieldName string, idx, argIdx int) *Location
MessageFieldOneofDefMessageArgumentLocation creates location for def[*].message.args[*] in grpc.federation.field.oneof.
func MessageFieldOneofDefMessageLocation ¶ added in v0.7.0
MessageFieldOneofDefMessageLocation creates location for def[*].message in grpc.federation.field.oneof.
func MessageFieldOneofDefaultLocation ¶ added in v0.3.0
MessageFieldOneofDefaultLocation creates location for default in grpc.federation.field.oneof option.
func MessageFieldOneofIfLocation ¶ added in v0.7.0
MessageFieldOneofIfLocation creates location for if in grpc.federation.field.oneof option.
func MessageFieldOneofLocation ¶ added in v0.3.0
MessageFieldOneofLocation creates location for oneof in grpc.federation.field option.
func MessageFieldOptionLocation ¶
MessageFieldOptionLocation creates location for grpc.federation.field option.
func MessageLocation ¶
MessageLocation creates location for message name.
func MessageOptionLocation ¶
MessageOptionLocation creates location for grpc.federaiton.message option.
func MethodLocation ¶
MethodLocation creates location for def[*].call.method in grpc.federation.message.
func MethodRetryConstantIntervalLocation ¶
MethodRetryConstantIntervalLocation creates location for def[*].call.retry.constant.interval in grpc.federation.message.
func MethodRetryExponentialInitialIntervalLocation ¶
MethodRetryExponentialInitialIntervalLocation creates location for def[*].call.retry.exponential.initial_interval in grpc.federation.message.
func MethodRetryExponentialMaxIntervalLocation ¶
MethodRetryExponentialMaxIntervalLocation creates location for def[*].call.retry.exponential.max_interval in grpc.federation.message.
func MethodTimeoutLocation ¶
MethodTimeoutLocation creates location for def[*].call.timeout in grpc.federation.message.
func OneofOptionLocation ¶
OneofOptionLocation creates location for grpc.federaiton.oneof option.
func RequestByLocation ¶
RequestByLocation creates location for def[*].call.request[*].by in grpc.federation.message.
func RequestFieldLocation ¶
RequestFieldLocation creates location for def[*].call.request[*].field in grpc.federation.message.
func ServiceDependencyLocation ¶
ServiceDependencyLocation creates location for service dependencies.
func ServiceDependencyNameLocation ¶
ServiceDependencyNameLocation creates location for name of service dependencies.
func ServiceDependencyServiceLocation ¶
ServiceDependencyServiceLocation creates location for service of service dependencies.
func ServiceLocation ¶
ServiceLocation creates location for service name.
func ServiceMethodLocation ¶
ServiceMethodLocation creates location for method of service.
func ServiceMethodOptionLocation ¶
ServiceMethodOptionLocation creates location for grpc.federation.method option.
func ServiceMethodRequestLocation ¶
ServiceMethodRequestLocation creates location for method request type of service.
func ServiceMethodResponseLocation ¶
ServiceMethodResponseLocation creates location for method response type of service.
func ServiceMethodTimeoutLocation ¶
ServiceMethodTimeoutLocation creates location for timeout of grpc.federation.method option.
func ServiceOptionLocation ¶
ServiceOptionLocation creates location for grpc.federation.service option.
func ValidationDetailBadRequestLocation ¶ added in v0.7.0
func ValidationDetailBadRequestLocation(fileName, msgName string, vIdx, dIdx, bIdx, fvIdx int, fieldName string) *Location
ValidationDetailBadRequestLocation creates location for def[*].validation.error.details[*].bad_request[*] in grpc.federation.message.
func ValidationDetailLocalizedMessageLocation ¶ added in v0.7.0
func ValidationDetailLocalizedMessageLocation(fileName, msgName string, vIdx, dIdx, lIdx int, fieldName string) *Location
ValidationDetailLocalizedMessageLocation creates location for def[*].validation.error.details[*].localized_message[*] in grpc.federation.message.
func ValidationDetailLocation ¶ added in v0.7.0
ValidationDetailLocation creates location for def[*].validation.error.details[*] in grpc.federation.message.
func ValidationDetailPreconditionFailureLocation ¶ added in v0.7.0
func ValidationDetailPreconditionFailureLocation(fileName, msgName string, vIdx, dIdx, fIdx, fvIdx int, fieldName string) *Location
ValidationDetailPreconditionFailureLocation creates location for def[*].validation.error.details[*].precondition_failure[*] in grpc.federation.message.
func ValidationLocation ¶ added in v0.7.0
ValidationLocation creates location for def[*].validation in grpc.federation.message.
func VariableDefinitionByLocation ¶ added in v0.6.0
VariableDefinitionByLocation creates location for def.by in grpc.federation.message.
func VariableDefinitionIfLocation ¶ added in v0.7.2
VariableDefinitionIfLocation creates location for def.if in grpc.federation.message.
func VariableDefinitionLocation ¶ added in v0.6.0
VariableDefinitionLocation creates location for def in grpc.federation.message.
func VariableDefinitionValidationDetailMessageArgumentLocation ¶ added in v0.7.0
func VariableDefinitionValidationDetailMessageArgumentLocation(fileName, msgName string, defIdx, detIdx, msgIdx, argIdx int) *Location
VariableDefinitionValidationDetailMessageArgumentLocation creates location for def.validation[*].error.details[*].message[*].args[*] in grpc.federation.message.
func VariableDefinitionValidationDetailMessageLocation ¶ added in v0.7.0
func VariableDefinitionValidationDetailMessageLocation(fileName, msgName string, defIdx, detIdx, msgIdx int) *Location
VariableDefinitionValidationDetailMessageLocation creates location for def.validation[*].error.details[*].message[*] in grpc.federation.message.
func VariableDefinitionValidationDetailMessageNameLocation ¶ added in v0.7.0
func VariableDefinitionValidationDetailMessageNameLocation(fileName, msgName string, defIdx, detIdx, msgIdx int) *Location
VariableDefinitionValidationDetailMessageNameLocation creates location for def.validation[*].error.details[*].message[*] in grpc.federation.message.
type MapExprOption ¶ added in v0.6.0
type MapExprOption struct {
Iterator *IteratorOption
By bool
Message *MessageExprOption
}
MapExprOption represents def.map location of grpc.federation.message option.
type Message ¶
type Message struct {
Name string
Option *MessageOption
Field *Field
Enum *Enum
Oneof *Oneof
}
Message represents message location.
type MessageExprOption ¶ added in v0.6.0
type MessageExprOption struct {
Name bool
Args *ArgumentOption
}
MessageExprOption represents def.message location of grpc.federation.message option.
type MessageOption ¶
type MessageOption struct {
VariableDefinitions *VariableDefinitionOption
Alias bool
}
MessageOption represents grpc.federation.message option location.
type Method ¶
type Method struct {
Name string
Request bool
Response bool
Option *MethodOption
}
Method represents service's method location.
type MethodOption ¶
type MethodOption struct {
Timeout bool
}
MethodOption represents grpc.federation.method option location.
type Oneof ¶
type Oneof struct {
Name string
Option *OneofOption
}
type OneofOption ¶
type OneofOption struct {
}
type RequestOption ¶
RequestOption represents resolver.request location of grpc.federation.message option.
type RetryConstantOption ¶
RetryConstantOption represents resolver.retry.constant location of grpc.federation.message option.
type RetryExponentialOption ¶
type RetryExponentialOption struct {
InitialInterval bool
RandomizationFactor bool
Multiplier bool
MaxInterval bool
MaxRetries bool
}
RetryExponentialOption represents resolver.retry.exponential location of grpc.federation.message option.
type RetryOption ¶
type RetryOption struct {
Constant *RetryConstantOption
Exponential *RetryExponentialOption
}
RetryOption represents resolver.retry location of grpc.federation.message option.
type Service ¶
type Service struct {
Name string
Method *Method
Option *ServiceOption
}
Service represents service location.
type ServiceDependencyOption ¶
ServiceDependencyOption represents dependencies option of service option.
type ServiceOption ¶
type ServiceOption struct {
Dependencies *ServiceDependencyOption
}
ServiceOption represents grpc.federation.service option location.
type ValidationDetailBadRequestFieldViolationOption ¶ added in v0.7.0
type ValidationDetailBadRequestOption ¶ added in v0.7.0
type ValidationDetailBadRequestOption struct {
Idx int
FieldViolation ValidationDetailBadRequestFieldViolationOption
}
type ValidationDetailLocalizedMessageOption ¶ added in v0.7.0
type ValidationDetailMessageOption ¶ added in v0.7.0
type ValidationDetailMessageOption struct {
Idx int
Message *MessageExprOption
}
type ValidationDetailOption ¶ added in v0.7.0
type ValidationDetailOption struct {
Idx int
If bool
Message *ValidationDetailMessageOption
PreconditionFailure *ValidationDetailPreconditionFailureOption
BadRequest *ValidationDetailBadRequestOption
LocalizedMessage *ValidationDetailLocalizedMessageOption
}
type ValidationDetailPreconditionFailureOption ¶ added in v0.7.0
type ValidationDetailPreconditionFailureOption struct {
Idx int
Violation ValidationDetailPreconditionFailureViolationOption
}
type ValidationDetailPreconditionFailureViolationOption ¶ added in v0.7.0
type ValidationExprOption ¶ added in v0.7.0
type ValidationExprOption struct {
Name bool
If bool
Detail *ValidationDetailOption
}
type VariableDefinitionOption ¶ added in v0.6.0
type VariableDefinitionOption struct {
Idx int
Name bool
If bool
By bool
Map *MapExprOption
Call *CallExprOption
Message *MessageExprOption
Validation *ValidationExprOption
}
VariableDefinitionOption represents def location of grpc.federation.message option.